<?php

/**
 * @file
 * Definition of Drupal\smallads\Form\SmallAdEdit.
 */

namespace Drupal\smallads\Form;

use Drupal\user\Entity\User;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\Core\Datetime\DrupalDateTime;

class SmallAdEdit extends ContentEntityForm {

  private $type_term_tid;

  /**
   * Constructs a SmallAdEdit object.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   * @param \Drupal\Core\Routing\RouteMatchInterfacee $routeMatch
   */
  public function __construct(RouteMatchInterface $routeMatch, $requestStack) {
    $this->query = $requestStack->getCurrentRequest()->query;
    $this->routeMatch = $routeMatch;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_route_match'),
      $container->get('request_stack')
    );
  }

  /**
   * Overrides Drupal\Core\Entity\ContentEntityForm::form().
   */
  public function form(array $form, FormStateInterface $form_state) {

    if ($this->query->has('strapline')) {
      $this->entity->strapline->value = $this->query->get('strapline');
    }

    if ($this->entity->isNew() && $this->routeMatch->getParameter('taxonomy_term')) {
      $form['type'] = [
        '#type' => 'value',
        '#value' => $this->routeMatch->getParameter('taxonomy_term')
      ];
    }
    //drupal_set_title();//@todo find out what happened to drupal_set_title

    $form = parent::form($form, $form_state);
    $form['scope']['widget'][0]['value']['#type'] = 'select';
    $form['scope']['widget'][0]['value']['#options'] = $this->getScopes(FALSE);

        //@todo remove this once the datetime field is fixed: https://www.drupal.org/node/2507775
    if ($this->entity->isNew()) {
      $def = DrupalDateTime::createFromTimestamp(strtotime(\Drupal::config('smallads.conf')->get('default_expiry')));
      $form['expires']['widget'][0]['value']['#default_value'] = $def;
    }

    //@todo set the min and max dates on $this->entity->expires - but how?
    $form['published'] = [
      '#title' => $this->t('Visibilty'),
      '#description' => $this->t("When the ad expires, the scope reverts to 'Owner only'."),
      '#type' => 'details',
      '#open' => $this->entity->scope > 0,
      '#weight' => 25,
      'expires' => $form['expires'],
      'scope' => $form['scope']
    ];
    unset($form['expires']);
    unset($form['scope']);

    $form['uid']['widget'][0]['target_id']['#access'] = \Drupal::currentUser()->hasPermission('edit propositions');

    return $form;
  }

  public function validate(array $form, FormStateInterface $form_state) {

    //entity->expires->getValue() is a dateTime Object
    $this->entity = parent::validate($form, $form_state);//this does createDateFromFormat
   //entity->expires->getValue()is [0] => Array([value] => 2015-06-24)


    //couldn't be bothered to do proper entity validation, only form validation
    $diff = strtotime($this->entity->expires->value) > REQUEST_TIME;
    if ($diff > 0) {//expires in the future
      if ($this->entity->scope == SMALLAD_SCOPE_PRIVATE) {
        $message = $this->t('If the expiry date is after now, the scope must not be private');
        $form_state->setErrorByName('scope', $message);
      }
    }
    else {//expires in the past
      if ($this->entity->scope != SMALLAD_SCOPE_PRIVATE) {
        $message = $this->t('If the article is to be visible, the expiry must be AFTER now.');
        $form_state->setErrorByName('scope', $message);
      }
    }
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    if ($this->entity->expires->value > REQUEST_TIME) {
      drupal_set_message(
        $this->t(
          'The @type will expire on @date',
          [
            '@type' => Term::load($form_state->get('type_term_tid'))->label(),
            '@date' => $this->entity->expires->view()[0]['#markup']
          ]
        )
      );
      //alternative...
      //drupal_set_message(
      //  'Your ad will expire in @days days.',
      //  ['@days' => \Drupal::service('date.formatter')->formatInterval($diff, 2, $format)]
      //);
    }
    else {
      //drupal_set_message() seems not to survive the redirect
      drupal_set_message(
        'The @type is only visible to you',
        ['@type' => $this->entity->type->entity->label()]
      );
    }
  }

  function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirect('entity.smallad.canonical', ['smallad' => $this->entity->id()]);
  }

  private function getScopes($include_private = TRUE) {
    $scopes = [];
    if ($include_private) {
      $scopes[SMALLAD_SCOPE_PRIVATE] = $this->t('Owner only');
    }
    if (\Drupal::moduleHandler()->moduleExists('og')) {
      $scopes[SMALLAD_SCOPE_OG] = $this->t('Members of the my groups');
    }
    $scopes[SMALLAD_SCOPE_SITE] = $this->t('This site');
    //$scopes[SMALLAD_SCOPE_NETWORK] = $this->t('Network');
    $scopes[SMALLAD_SCOPE_PUBLIC] = $this->t('Anyone');
    return $scopes;
  }

}
