<?php

/**
 * @file
 * Contains \Drupal\smallads\Plugin\Condition\AdContext.
 */

namespace Drupal\smallads\Plugin\Condition;

use Drupal\Core\Condition\ConditionPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Transaction is in state' condition.
 * @todo see https://www.drupal.org/node/2284687
 * show this only on ad blocks
 *
 * @Condition(
 *   id = "ad_context",
 *   label = @Translation("Ad page"),
 *   category = @Translation("Small ads"),
 *   context = { }
 * )
 *
 */
class AdContext extends ConditionPluginBase {

  /**
   * {@inheritdoc}
   */
  public function summary() {
    return $this->configuration['ad_page'] ?
      $this->t('Only on ad pages') :
      $this->t('Except on ad_pages');
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'ad_page' => TRUE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['ad_page'] = [
      '#title' => $this->t('Only on ad pages'),
      '#type' => 'checkbox',
      '#default_value' => $this->configuration['ad_page'],
    ];
    return $form;
  }
  /**
   * {@inheritdoc}
   */
  public function evaluate() {
    if ($this->configuration['ad_page'] && smallad_type_from_route_match()) {
      return TRUE;
    }
    else return TRUE;
  }

}
