<?php

/**
 * @file
 * Contains \Drupal\smallads\Plugin\Derivative\SmallAdMenuLink.
 */

namespace Drupal\smallads\Plugin\Derivative;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides menu links definitions to connect to the auto view
 */
class SmallAdMenuLink extends DeriverBase implements ContainerDeriverInterface {

  var $derivatives = [];
  var $termStorage = [];

  /**
   * {@inheritDoc}
   *
   */
  public function __construct($termStorage) {
    $this->termStorage = $termStorage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity.manager')->getStorage('taxonomy_term')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    //a link to add each type of add. These can be moved around by user 1
    foreach (smallads_get_types(TRUE) as $tid => $term) {
      $route_name = 'smallad.add.'.$tid;
      $links['smallad.add.{$tid}.link'] = [
        'title' => 'Add @type',
        //@todo I don't know how to translate the title
        'title_arguments' => ['@type' => $term->label()],
        'route_name' => 'smallad.add',
        'route_parameters' => ['taxonomy_term' => $tid],
        'provider' => 'smallads',
        'menu_name' => 'tools',//@todo find somewhere better to put these
        //'parent' => '',
        'weight' => $term->weight->value
      ];
    }
    /*
    //main menu links to the categories view.
    //under these are tabs, see \Drupal\smallads\Plugin\Derivative\SmallAdTasks
    foreach ($this->termStorage->loadTree('smallad_types') as $type) {
      //assumes bundle names don't clash!
      $this->derivatives['ads.autoviews.'.$type->tid] = [
        'title' => $type->name,//is this translated later?
        'description' => $type->description__value,//is this translated later?
        'parent' => '',
        'route_name' => 'view.ads.page_all.'.$type->tid,//taken from the routesubscriber
        'route_parameters' => ['arg_0' => $type->tid],
        'menu_name' => 'main'
      ]+ $base_plugin_definition;
    }
     *
     */



    //@todo might be nice to have some translated aliases for this
    //path is currently ads/{$tid} whereas '/offers' would be nicer
    return $this->derivatives;
  }
}
